==> mx-packageinstaller-pkglist_19.07.06.tar.xz: mx-packageinstaller-pkglist/smplayer.pm <==
<?xml version="1.0"?>
<app>

<category>
Video
</category>

<name>
SMplayer
</name>

<description>
   <am>themable gui frontend to MPlayer with other interesting features</am>
   <ar>themable gui frontend to MPlayer with other interesting features</ar>
   <bg>themable gui frontend to MPlayer with other interesting features</bg>
   <ca>Frontal IGU configurable per MPlayer amb característiques interessants</ca>
   <cs>themable gui frontend to MPlayer with other interesting features</cs>
   <da>grafisk brugerflade-frontend med temaer til MPlayer med andre interessante funktionaliteter</da>
   <de>Themen-anpassbares GUI-Frontend zu MPlayer mit weiteren interessanten Funktionen</de>
   <el>διασκεδαστικό gui frontend στο MPlayer με άλλα ενδιαφέροντα χαρακτηριστικά</el>
   <en>themable gui frontend to MPlayer with other interesting features</en>
   <es>frontend para MPlayer, con interesantes funcionalidades y GUI personalizable.</es>
   <et>themable gui frontend to MPlayer with other interesting features</et>
   <eu>themable gui frontend to MPlayer with other interesting features</eu>
   <fa>themable gui frontend to MPlayer with other interesting features</fa>
   <fi>themable gui frontend to MPlayer with other interesting features</fi>
   <fr>Interface graphique/frontend personnalisable pour MPlayer avec fonctionnalités utiles</fr>
   <he_IL>themable gui frontend to MPlayer with other interesting features</he_IL>
   <hi>themable gui frontend to MPlayer with other interesting features</hi>
   <hr>themable gui frontend to MPlayer with other interesting features</hr>
   <hu>themable gui frontend to MPlayer with other interesting features</hu>
   <id>themable gui frontend to MPlayer with other interesting features</id>
   <is>themable gui frontend to MPlayer with other interesting features</is>
   <it>interfaccia grafica per MPlayer con ulteriori interessanti funzionalità</it>
   <ja_JP>themable gui frontend to MPlayer with other interesting features</ja_JP>
   <ja>themable gui frontend to MPlayer with other interesting features</ja>
   <kk>themable gui frontend to MPlayer with other interesting features</kk>
   <ko>themable gui frontend to MPlayer with other interesting features</ko>
   <lt>themable gui frontend to MPlayer with other interesting features</lt>
   <mk>themable gui frontend to MPlayer with other interesting features</mk>
   <nb>themable gui frontend to MPlayer with other interesting features</nb>
   <nl>gui die van thema's kan worden voorzien, frontend voor MPlayer met andere interessante functies</nl>
   <pl>tematyczna nakładka na GUI do MPlayera z innymi ciekawymi funkcjami</pl>
   <pt_BR>themable gui frontend to MPlayer with other interesting features</pt_BR>
   <pt>Interface gráfica para o MPlayer com vários temas e com outras funcionalidades interessantes</pt>
   <ro>themable gui frontend to MPlayer with other interesting features</ro>
   <ru>Графическая оболочка для MPlayer с множеством фишек</ru>
   <sk>themable gui frontend to MPlayer with other interesting features</sk>
   <sl>themable gui frontend to MPlayer with other interesting features</sl>
   <sq>themable gui frontend to MPlayer with other interesting features</sq>
   <sr>themable gui frontend to MPlayer with other interesting features</sr>
   <sv>temabar grafisk front-end till MPlayer med andra intressanta möjligheter</sv>
   <tr>themable gui frontend to MPlayer with other interesting features</tr>
   <uk>themable gui frontend to MPlayer with other interesting features</uk>
   <zh_CN>themable gui frontend to MPlayer with other interesting features</zh_CN>
   <zh_TW>themable gui frontend to MPlayer with other interesting features</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/015/414/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
smplayer
smplayer-themes
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
smplayer
smplayer-themes
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.02.tar.xz: mx-packageinstaller-pkglist/smplayer.pm <==
<?xml version="1.0"?>
<app>

<category>
Video
</category>

<name>
SMplayer
</name>

<description>
   <am>themable gui frontend to MPlayer with other interesting features</am>
   <ar>themable gui frontend to MPlayer with other interesting features</ar>
   <bg>themable gui frontend to MPlayer with other interesting features</bg>
   <ca>Frontal IGU configurable per MPlayer amb característiques interessants</ca>
   <cs>themable gui frontend to MPlayer with other interesting features</cs>
   <da>grafisk brugerflade-frontend med temaer til MPlayer med andre interessante funktionaliteter</da>
   <de>Themen-anpassbares GUI-Frontend zu MPlayer mit weiteren interessanten Funktionen</de>
   <el>διασκεδαστικό gui frontend στο MPlayer με άλλα ενδιαφέροντα χαρακτηριστικά</el>
   <en>themable gui frontend to MPlayer with other interesting features</en>
   <es>Interfaz gráfica de usuario temática para MPlayer con otras características interesantes</es>
   <et>themable gui frontend to MPlayer with other interesting features</et>
   <eu>themable gui frontend to MPlayer with other interesting features</eu>
   <fa>themable gui frontend to MPlayer with other interesting features</fa>
   <fi>themable gui frontend to MPlayer with other interesting features</fi>
   <fr>Interface graphique/frontend personnalisable pour MPlayer avec fonctionnalités utiles</fr>
   <he_IL>themable gui frontend to MPlayer with other interesting features</he_IL>
   <hi>themable gui frontend to MPlayer with other interesting features</hi>
   <hr>themable gui frontend to MPlayer with other interesting features</hr>
   <hu>themable gui frontend to MPlayer with other interesting features</hu>
   <id>themable gui frontend to MPlayer with other interesting features</id>
   <is>themable gui frontend to MPlayer with other interesting features</is>
   <it>interfaccia grafica per MPlayer con ulteriori interessanti funzionalità</it>
   <ja_JP>themable gui frontend to MPlayer with other interesting features</ja_JP>
   <ja>themable gui frontend to MPlayer with other interesting features</ja>
   <kk>themable gui frontend to MPlayer with other interesting features</kk>
   <ko>themable gui frontend to MPlayer with other interesting features</ko>
   <lt>themable gui frontend to MPlayer with other interesting features</lt>
   <mk>themable gui frontend to MPlayer with other interesting features</mk>
   <nb>themable gui frontend to MPlayer with other interesting features</nb>
   <nl>gui die van thema's kan worden voorzien, frontend voor MPlayer met andere interessante functies</nl>
   <pl>tematyczna nakładka na GUI do MPlayera z innymi ciekawymi funkcjami</pl>
   <pt_BR>Interface gráfica para o MPlayer com vários temas e com outras funcionalidades interessantes</pt_BR>
   <pt>Interface gráfica para o MPlayer com vários temas e com outras funcionalidades interessantes</pt>
   <ro>themable gui frontend to MPlayer with other interesting features</ro>
   <ru>Графическая оболочка для MPlayer с множеством фишек</ru>
   <sk>themable gui frontend to MPlayer with other interesting features</sk>
   <sl>themable gui frontend to MPlayer with other interesting features</sl>
   <sq>themable gui frontend to MPlayer with other interesting features</sq>
   <sr>themable gui frontend to MPlayer with other interesting features</sr>
   <sv>temabar grafisk front-end till MPlayer med andra intressanta möjligheter</sv>
   <tr>themable gui frontend to MPlayer with other interesting features</tr>
   <uk>themable gui frontend to MPlayer with other interesting features</uk>
   <zh_CN>themable gui frontend to MPlayer with other interesting features</zh_CN>
   <zh_TW>themable gui frontend to MPlayer with other interesting features</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/015/414/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
smplayer
smplayer-themes
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
smplayer
smplayer-themes
</uninstall_package_names>
</app>
